@@ -57,6 +57,15 @@ BRAILLE_DOT_8 = _("Dot _8")
 # "marking"/indicating that a given word is bold.
 BRAILLE_DOT_7_8 = _("Dots 7 an_d 8")
 
+# Translators: This is the label for a button in a dialog.
+BTN_CANCEL = _("_Cancel")
+
+# Translators: This is the label for a button in a dialog.
+BTN_JUMP_TO = _("_Jump to")
+
+# Translators: This is the label for a button in a dialog.
+BTN_OK = _("_OK")
+
 # Translators: Orca has had to implement its own caret navigation model to work
 # around issues in Gecko/Firefox. In some versions of Firefox, we must perform
 # a focus grab on each object being navigated in order for things to work as
@@ -392,6 +401,14 @@ SN_HEADER_HEADING = C_("structural navigation", "Heading")
 # contains the label of a form field.
 SN_HEADER_LABEL = C_("structural navigation", "Label")
 
+# Translators: Orca has a command that presents a list of structural navigation
+# objects in a dialog box so that users can navigate more quickly than they
+# could with native keyboard navigation. This is the title for a column which
+# contains the text of a landmark. ARIA role landmarks are the W3C defined HTML
+# tag attribute 'role' used to identify important part of webpage like banners,
+# main context, search etc.
+SN_HEADER_LANDMARK = C_("structural navigation", "Landmark")
+
 # Translators: Orca has a command that presents a list of structural navigation
 # objects in a dialog box so that users can navigate more quickly than they
 # could with native keyboard navigation. This is the title of a column which
@@ -514,6 +531,13 @@ SN_TITLE_HEADING = C_("structural navigation", "Headings")
 # Level will be a "1" for <h1>, a "2" for <h2>, and so on.
 SN_TITLE_HEADING_AT_LEVEL = C_("structural navigation", "Headings at Level %d")
 
+# Translators: Orca has a command that presents a list of structural navigation
+# objects in a dialog box so that users can navigate more quickly than they
+# could with native keyboard navigation. This is the title of such a dialog box.
+# ARIA role landmarks are the W3C defined HTML tag attribute 'role' used to
+# identify important part of webpage like banners, main context, search etc.
+SN_TITLE_LANDMARK = C_("structural navigation", "Landmarks")
+
 # Translators: Orca has a command that presents a list of structural navigation
 # objects in a dialog box so that users can navigate more quickly than they
 # could with native keyboard navigation. This is the title of such a dialog box.
