@@ -123,6 +123,7 @@ class Script(Gecko.Script):
             return
 
         self._lastAutoComplete = ""
+        self.pointOfReference['lastAutoComplete'] = None
 
         obj = event.source
         if not self.inDocumentContent(obj):
@@ -154,6 +155,11 @@ class Script(Gecko.Script):
                 self.speakMessage(obj.name)
                 self._presentMessage(obj)
 
+    def onChildrenChanged(self, event):
+        """Callback for object:children-changed accessibility events."""
+
+        default.Script.onChildrenChanged(self, event)
+
     def onShowingChanged(self, event):
         """Callback for object:state-changed:showing accessibility events."""
 
@@ -212,7 +218,7 @@ class Script(Gecko.Script):
                 default.Script.onTextInserted(self, event)
                 return
 
-            if self._lastAutoComplete == event.any_data:
+            if self._lastAutoComplete and self._lastAutoComplete in event.any_data:
                 return
 
             # Mozilla cannot seem to get their ":system" suffix right
@@ -231,6 +237,11 @@ class Script(Gecko.Script):
 
         Gecko.Script.onTextInserted(self, event)
 
+    def onTextSelectionChanged(self, event):
+        """Callback for object:text-selection-changed accessibility events."""
+
+        default.Script.onTextSelectionChanged(self, event)
+
     def onNameChanged(self, event):
         """Called whenever a property on an object changes.
 
