@@ -28,6 +28,7 @@ __license__   = "LGPL"
 import pyatspi
 
 import orca.orca as orca
+import orca.orca_state as orca_state
 import orca.scripts.default as default
 
 class Script(default.Script):
@@ -44,6 +45,16 @@ class Script(default.Script):
 
         role = event.source.getRole()
 
+        # https://bugzilla.gnome.org/show_bug.cgi?id=720987
+        if role == pyatspi.ROLE_TABLE_COLUMN_HEADER:
+            orca.setLocusOfFocus(event, event.source)
+            return
+
+        # https://bugzilla.gnome.org/show_bug.cgi?id=720989
+        if role == pyatspi.ROLE_MENU == event.source.parent.getRole():
+            orca.setLocusOfFocus(event, event.source)
+            return
+
         # Unfiled. But this happens when you are in gtk-demo's application demo,
         # get into a menu and then press Escape. The text widget emits a focus:
         # event, but not a state-changed:focused event.
@@ -78,3 +89,12 @@ class Script(default.Script):
 
             orca.setLocusOfFocus(event, obj)
             return
+
+    def onTextSelectionChanged(self, event):
+        """Callback for object:text-selection-changed accessibility events."""
+
+        obj = event.source
+        if not self.utilities.isSameObject(obj, orca_state.locusOfFocus):
+            return
+
+        default.Script.onTextSelectionChanged(self, event)
