@@ -72,6 +72,16 @@ class Script(default.Script):
             orca.setLocusOfFocus(event, event.source)
             return
 
+        # https://bugzilla.gnome.org/show_bug.cgi?id=720987
+        if role == pyatspi.ROLE_TABLE_COLUMN_HEADER:
+            orca.setLocusOfFocus(event, event.source)
+            return
+
+        # https://bugzilla.gnome.org/show_bug.cgi?id=720989
+        if role == pyatspi.ROLE_MENU == event.source.parent.getRole():
+            orca.setLocusOfFocus(event, event.source)
+            return
+
         # Unfiled, but a similar case of the above issue with combo boxes.
         if role == pyatspi.ROLE_PUSH_BUTTON:
             orca.setLocusOfFocus(event, event.source)
@@ -112,3 +122,12 @@ class Script(default.Script):
 
             orca.setLocusOfFocus(event, obj)
             return
+
+    def onTextSelectionChanged(self, event):
+        """Callback for object:text-selection-changed accessibility events."""
+
+        obj = event.source
+        if not self.utilities.isSameObject(obj, orca_state.locusOfFocus):
+            return
+
+        default.Script.onTextSelectionChanged(self, event)
